import { themes as prismThemes } from 'prism-react-renderer';
import type { Config } from '@docusaurus/types';
import type * as Preset from '@docusaurus/preset-classic';

const config: Config = {
	title: 'OpenDMP',
	tagline: 'OpenDMP',
	favicon: 'img/favicon.ico',

	// Set the production url of your site here
	url: 'https://your-docusaurus-site.example.com',
	// Set the /<baseUrl>/ pathname under which your site is served
	// For GitHub pages deployment, it is often '/<projectName>/'
	baseUrl: '/',

	// GitHub pages deployment config.
	// If you aren't using GitHub pages, you don't need these.
	organizationName: 'facebook', // Usually your GitHub org/user name.
	projectName: 'docusaurus', // Usually your repo name.

	onBrokenLinks: 'throw',
	onBrokenMarkdownLinks: 'warn',

	// Even if you don't use internationalization, you can use this field to set
	// useful metadata like html lang. For example, if your site is Chinese, you
	// may want to replace "en" with "zh-Hans".
	i18n: {
		defaultLocale: 'en',
		locales: ['en'],
	},

	presets: [
		[
			'classic',
			{
				docs: {
					sidebarPath: './sidebars.ts',
					// Please change this to your repo.
					// Remove this to remove the "edit this page" links.
					editUrl:
						'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
				},
				blog: {
					showReadingTime: true,
					// Please change this to your repo.
					// Remove this to remove the "edit this page" links.
					editUrl:
						'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
				},
				theme: {
					customCss: './src/css/custom.css',
				},
			} satisfies Preset.Options,
		],
	],

	themeConfig: {
		// Replace with your project's social card
		image: 'img/docusaurus-social-card.jpg',
		navbar: {
			title: 'OpenDMP',
			logo: {
				alt: 'OpenDMP Logo',
				src: 'img/logo.svg',
			},
			items: [
				{
					type: 'docSidebar',
					sidebarId: 'documentationSidebar',
					position: 'left',
					label: 'Documentation',
				},
				{
					type: 'docSidebar',
					sidebarId: 'tutorialSidebar',
					position: 'left',
					label: 'Tutorials',
				},
				{
					href: 'https://test4.opendmp.eu/splash/',
					label: 'Visit OpenDMP',
					position: 'right',
				},
			],
		},
		footer: {
			style: 'dark',
			links: [
				{
					title: 'Docs',
					items: [
						{
							label: 'Getting Started',
							to: '/docs/category/getting-started',
						},
						{
							label: 'Application',
							to: '/docs/category/application',
						},
						{
							label: 'Supplementary Services',
							to: '/docs/category/supplementary-services',
						},
						{
							label: 'Administration',
							to: '/docs/documentation/administration',
						},
						{
							label: 'For Developers',
							to: '/docs/category/for-developers',
						},
					],
				},
				{
					title: 'Community',
					items: [
						// {
						// 	label: 'Stack Overflow',
						// 	href: 'https://stackoverflow.com/questions/tagged/docusaurus',
						// },
						// {
						// 	label: 'Discord',
						// 	href: 'https://discordapp.com/invite/docusaurus',
						// },
						// {
						// 	label: 'Twitter',
						// 	href: 'https://twitter.com/docusaurus',
						// },
					],
				},
				{
					title: 'More',
					items: [
						{
							label: 'Website',
							href: 'https://test4.opendmp.eu/splash/',
						},
					],
				},
			],
			copyright: `Copyright © ${new Date().getFullYear()} OpenDMP. Built with Docusaurus.`,
		},
		prism: {
			theme: prismThemes.github,
			darkTheme: prismThemes.dracula,
		},
	} satisfies Preset.ThemeConfig,
};

export default config;
